==> grogupy-0.0.1-py3-none-any.whl: grogupy/config.py <==
# Copyright (c) [2024-2025] [Laszlo Oroszlany, Daniel Pozsar]
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
from os import environ

from . import __all__


class Config:
    def __init__(self, architecture: str):
        self.__viz_loaded = False

        if architecture[0].lower() == "c":
            self.__architecture = "CPU"
        elif architecture[0].lower() == "g":
            self.__architecture = "GPU"
        else:
            raise Exception("Unknown architecture, use CPU or GPU!")

        if self.__architecture == "CPU":
            from mpi4py import MPI

            self.__parallel_size = MPI.COMM_WORLD.Get_size()

        elif self.__architecture == "GPU":
            import cupy as cp

            self.__parallel_size = cp.cuda.runtime.getDeviceCount()

    @property
    def viz_loaded(self):
        return self.__viz_loaded

    @property
    def architecture(self):
        return self.__architecture

    @property
    def parallel_size(self):
        return self.__parallel_size

    @property
    def is_CPU(self):
        return self.__architecture == "CPU"

    @property
    def is_GPU(self):
        return self.__architecture == "GPU"


CONFIG = Config(environ.get("grogupy_ARCHITECTURE", "CPU"))

__all__.extend(["CONFIG"])

==> grogupy-0.0.3-py3-none-any.whl: grogupy/config.py <==
# Copyright (c) [2024-2025] [Laszlo Oroszlany, Daniel Pozsar]
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
from os import environ

from . import __all__


class Config:
    def __init__(self, architecture: str):
        self.__viz_loaded = False

        if architecture.lower() == "cpu":
            self.__architecture = "CPU"
        elif architecture.lower() == "gpu":
            self.__architecture = "GPU"
        else:
            raise Exception("Unknown architecture, use CPU or GPU!")

        if self.__architecture == "CPU":
            from mpi4py import MPI

            self.__parallel_size = MPI.COMM_WORLD.Get_size()

        elif self.__architecture == "GPU":
            import cupy as cp

            self.__parallel_size = cp.cuda.runtime.getDeviceCount()

    @property
    def viz_loaded(self):
        return self.__viz_loaded

    @property
    def architecture(self):
        return self.__architecture

    @property
    def parallel_size(self):
        return self.__parallel_size

    @property
    def is_CPU(self):
        return self.__architecture == "CPU"

    @property
    def is_GPU(self):
        return self.__architecture == "GPU"


CONFIG = Config(environ.get("GROGUPY_ARCHITECTURE", "CPU"))

__all__.extend(["CONFIG"])

if __name__ == "__main__":
    pass
